==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/File/NewFile/ts/NewFile_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>CloseDialog</name>
    <message>
        <location filename="../CloseDialog.ui" line="+14"/>
        <source>Closing Drawing...</source>
        <translation>Chiusura del disegno...</translation>
    </message>
</context>
<context>
    <name>Form</name>
    <message>
        <location filename="../MdiChildEmpty.ui" line="+20"/>
        <source>Untitled</source>
        <translation>Senza titolo</translation>
    </message>
</context>
<context>
    <name>NewFile</name>
    <message>
        <source>Untitled %1 [*]</source>
        <translation type="obsolete">Senza titolo %1 [*]</translation>
    </message>
    <message>
        <location filename="../NewFile.js" line="+120"/>
        <source>Loading...</source>
        <translation>Caricamento…</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Import Error</source>
        <translation>Errore di importazione</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Cannot open file</source>
        <translation>Impossibile aprire il file</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>No suitable Importer found. Please check file format and extension.</source>
        <translation>Nessun Importatore trovato adatto. Si prega di controllare formato file e l&apos;estensione.</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Please check your access rights, the file format and file extension.</source>
        <translation>Si prega di controllare i diritti di accesso, il formato del file e l&apos;estensione del file.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>File is empty.</source>
        <translation>Il file è vuoto.</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Opened drawing:</source>
        <translation>Disegno aperto:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Format:</source>
        <translation>Formato:</translation>
    </message>
    <message>
        <location line="+92"/>
        <source>Untitled %1</source>
        <translation>Senza titolo %1</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>read-only</source>
        <translation>Sola lettura</translation>
    </message>
    <message>
        <location line="+41"/>
        <source>Do you want to save the changes you made in&lt;br&gt;the document &apos;%1&apos;?</source>
        <translation>Volete salvare le modifiche apportate nel&lt;br&gt;documento &apos;%1&apos;?</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>Le modifiche andranno perdute se non li salva.</translation>
    </message>
    <message>
        <location filename="../NewFileInit.js" line="+2"/>
        <source>&amp;New</source>
        <translation>&amp;Nuovo</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/File/NewFile/ts/NewFile_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>CloseDialog</name>
    <message>
        <location filename="../CloseDialog.ui" line="+14"/>
        <source>Closing Drawing...</source>
        <translation>Chiusura del disegno...</translation>
    </message>
</context>
<context>
    <name>Form</name>
    <message>
        <location filename="../MdiChildEmpty.ui" line="+20"/>
        <source>Untitled</source>
        <translation>Senza titolo</translation>
    </message>
</context>
<context>
    <name>NewFile</name>
    <message>
        <source>Untitled %1 [*]</source>
        <translation type="obsolete">Senza titolo %1 [*]</translation>
    </message>
    <message>
        <location filename="../NewFile.js" line="+114"/>
        <source>Opening drawing:</source>
        <translation>Aprendo il disegno:</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation type="vanished">Caricamento…</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Import Error</source>
        <translation>Errore di importazione</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Cannot open file</source>
        <translation>Impossibile aprire il file</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>No suitable Importer found. Please check file format and extension.</source>
        <translation>Nessun Importatore trovato adatto. Si prega di controllare formato file e l&apos;estensione.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>File not found.</source>
        <translation>File non trovato.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Please check your access rights, the file format and file extension.</source>
        <translation>Si prega di controllare i diritti di accesso, il formato del file e l&apos;estensione del file.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Import failed.</source>
        <translation>Importazione non riuscita.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>File is empty.</source>
        <translation>Il file è vuoto.</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Drawing loaded successfully:</source>
        <translation>Disegno caricato correttamente:</translation>
    </message>
    <message>
        <source>Opened drawing:</source>
        <translation type="vanished">Disegno aperto:</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Format:</source>
        <translation>Formato:</translation>
    </message>
    <message>
        <location line="+124"/>
        <source>Untitled %1</source>
        <translation>Senza titolo %1</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>read-only</source>
        <translation>Sola lettura</translation>
    </message>
    <message>
        <location line="+53"/>
        <source>Do you want to save the changes you made in&lt;br&gt;the document &apos;%1&apos;?</source>
        <translation>Volete salvare le modifiche apportate nel&lt;br&gt;documento &apos;%1&apos;?</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>Le modifiche andranno perdute se non li salva.</translation>
    </message>
    <message>
        <location filename="../NewFileInit.js" line="+2"/>
        <source>&amp;New</source>
        <translation>&amp;Nuovo</translation>
    </message>
</context>
</TS>
